@@ -1,8 +1,8 @@
 import json
 import uuid
-from typing import Iterable, Callable, Optional
+from typing import Callable, Iterable, Optional
 
-import boto3 as boto3
+import boto3
 
 from fastapi_events.errors import ConfigurationError
 from fastapi_events.handlers.base import BaseEventHandler
@@ -10,7 +10,7 @@ from fastapi_events.typing import Event
 from fastapi_events.utils import chunk
 
 
-def _uuid4_generator(event: Event) -> str:
+def _uuid4_generator(_: Event) -> str:
     return str(uuid.uuid4())
 
 
@@ -28,9 +28,9 @@ class SQSForwardHandler(BaseEventHandler):
         self,
         queue_url: str,
         region_name: str,
-        serializer: Callable[[Event], str] = None,
-        id_generator: Callable[[Event], str] = None,
-        max_batch_size: Optional[int] = 10,  # AWS supports up to 10 messages at once
+        serializer: Optional[Callable[[Event], str]] = None,
+        id_generator: Optional[Callable[[Event], str]] = None,
+        max_batch_size: int = 10,  # AWS supports up to 10 messages at once
         **boto_client_kwargs
     ):
         for fn in (serializer, id_generator):
